@@ -1,7 +1,7 @@
 import logging
 import time
 from copy import deepcopy
-from typing import TYPE_CHECKING, Callable, Optional, Sequence, Tuple
+from typing import Callable, Optional, Sequence, TYPE_CHECKING, Tuple
 
 from injector import inject
 from transitions import State
@@ -21,38 +21,40 @@ if TYPE_CHECKING:
 
 class Monitor(State):
     @inject
-    def __init__(self, state_machine: "StateMachine"):
+    def __init__(self, state_machine: "StateMachine") -> None:
         super().__init__(name="monitor", on_enter=self.start, on_exit=self.stop)
         self.state_machine: "StateMachine" = state_machine
 
         self.logger = logging.getLogger("state_machine")
         self.step_status_thread: Optional[ThreadedRequest] = None
 
-    def start(self):
+    def start(self) -> None:
         self.state_machine.update_state()
         self._run()
 
-    def stop(self):
+    def stop(self) -> None:
         if self.step_status_thread:
             self.step_status_thread.wait_for_thread()
         self.step_status_thread = None
 
-    def _run(self):
+    def _run(self) -> None:
         transition: Callable
         while True:
             if self.state_machine.should_stop_mission():
-                transition = self.state_machine.stop
+                transition = self.state_machine.stop  # type: ignore
                 break
 
             if self.state_machine.should_pause_mission():
-                transition = self.state_machine.pause
+                transition = self.state_machine.pause  # type: ignore
                 break
 
             if not self.step_status_thread:
                 self.step_status_thread = ThreadedRequest(
                     self.state_machine.robot.step_status
                 )
-                self.step_status_thread.start_thread()
+                self.step_status_thread.start_thread(
+                    name="State Machine Monitor Current Step"
+                )
 
             try:
                 step_status: StepStatus = self.step_status_thread.get_output()
@@ -65,8 +67,12 @@ class Monitor(State):
             self.state_machine.current_step.status = step_status
 
             if self._step_finished(step=self.state_machine.current_step):
-                self._process_finished_step(step=self.state_machine.current_step)
-                transition = self.state_machine.step_finished
+                get_inspections_thread = ThreadedRequest(self._process_finished_step)
+                get_inspections_thread.start_thread(
+                    self.state_machine.current_step,
+                    name="State Machine Get Inspections",
+                )
+                transition = self.state_machine.step_finished  # type: ignore
                 break
 
             self.step_status_thread = None
@@ -74,7 +80,7 @@ class Monitor(State):
 
         transition()
 
-    def _queue_inspections_for_upload(self, current_step: InspectionStep):
+    def _queue_inspections_for_upload(self, current_step: InspectionStep) -> None:
         try:
             inspections: Sequence[
                 Inspection
@@ -85,6 +91,11 @@ class Monitor(State):
             )
             return
 
+        if not inspections:
+            self.logger.warning(
+                f"No inspection data retrieved for step {str(current_step.id)[:8]}"
+            )
+
         # A deepcopy is made to freeze the metadata before passing it to another thread
         # through the queue
         mission_metadata: MissionMetadata = deepcopy(
