@@ -5,9 +5,8 @@ from threading import Thread
 from typing import List
 
 import pytest
-import logging
-
 from injector import Injector
+from pytest_mock import MockerFixture
 
 from isar.mission_planner.local_planner import LocalPlanner
 from isar.models.communication.queues.queues import Queues
@@ -18,19 +17,19 @@ from isar.state_machine.state_machine import StateMachine, main
 from isar.state_machine.states_enum import States
 from isar.storage.storage_interface import StorageInterface
 from isar.storage.uploader import Uploader
+from robot_interface.models.exceptions import RobotException
 from robot_interface.models.mission import DriveToPose, Step, TakeImage
 from robot_interface.models.mission.status import StepStatus
 from tests.mocks.pose import MockPose
 from tests.mocks.robot_interface import MockRobot
 from tests.mocks.step import MockStep
-from pytest_mock import MockerFixture
 
 
 class StateMachineThread(object):
     def __init__(self, injector) -> None:
         self.injector: Injector = injector
         self.state_machine: StateMachine = injector.get(StateMachine)
-        self._thread: Thread = Thread(target=main, args=[injector])
+        self._thread: Thread = Thread(target=main, args=[self.state_machine])
         self._thread.daemon = True
         self._thread.start()
 
@@ -57,7 +56,7 @@ def uploader_thread(injector) -> UploaderThread:
     return UploaderThread(injector=injector)
 
 
-def get_mission():
+def get_mission() -> Mission:
     mission_reader: LocalPlanner = LocalPlanner()
     mission: Mission = mission_reader.read_mission_from_file(
         Path("./tests/test_data/test_mission_working.json")
@@ -65,17 +64,17 @@ def get_mission():
     return mission
 
 
-def test_initial_off(state_machine):
+def test_initial_off(state_machine) -> None:
     assert state_machine.state == "off"
 
 
-def test_send_status(state_machine):
+def test_send_status(state_machine) -> None:
     state_machine.send_state_status()
     message = state_machine.queues.state.check()
     assert message == state_machine.current_state
 
 
-def test_reset_state_machine(state_machine):
+def test_reset_state_machine(state_machine) -> None:
     state_machine.reset_state_machine()
 
     assert state_machine.current_step is None
@@ -86,9 +85,9 @@ def test_reset_state_machine(state_machine):
 empty_mission: Mission = Mission([], None)
 
 
-def test_state_machine_transitions(injector, state_machine_thread):
+def test_state_machine_transitions(injector, state_machine_thread) -> None:
     step: Step = DriveToPose(pose=MockPose.default_pose)
-    mission: Mission = Mission(tasks=[Task(steps=[step])])
+    mission: Mission = Mission(tasks=[Task(steps=[step])])  # type: ignore
 
     scheduling_utilities: SchedulingUtilities = injector.get(SchedulingUtilities)
     scheduling_utilities.start_mission(mission=mission, initial_pose=None)
@@ -109,10 +108,12 @@ def test_state_machine_transitions(injector, state_machine_thread):
     )
 
 
-def test_state_machine_failed_dependency(injector, state_machine_thread, mocker):
+def test_state_machine_failed_dependency(
+    injector, state_machine_thread, mocker
+) -> None:
     drive_to_step: Step = DriveToPose(pose=MockPose.default_pose)
     inspection_step: Step = MockStep.take_image_in_coordinate_direction
-    mission: Mission = Mission(tasks=[Task(steps=[drive_to_step, inspection_step])])
+    mission: Mission = Mission(tasks=[Task(steps=[drive_to_step, inspection_step])])  # type: ignore
 
     mocker.patch.object(MockRobot, "step_status", return_value=StepStatus.Failed)
 
@@ -137,7 +138,7 @@ def test_state_machine_failed_dependency(injector, state_machine_thread, mocker)
 
 def test_state_machine_with_successful_collection(
     injector, state_machine_thread, uploader_thread
-):
+) -> None:
     storage_mock: StorageInterface = injector.get(List[StorageInterface])[0]
 
     step: TakeImage = MockStep.take_image_in_coordinate_direction
@@ -157,7 +158,7 @@ def test_state_machine_with_successful_collection(
         ]
     )
     expected_stored_items = 1
-    assert len(storage_mock.stored_inspections) == expected_stored_items
+    assert len(storage_mock.stored_inspections) == expected_stored_items  # type: ignore
     assert (
         state_machine_thread.state_machine.transitions_list == expected_transitions_list
     )
@@ -165,7 +166,7 @@ def test_state_machine_with_successful_collection(
 
 def test_state_machine_with_unsuccessful_collection(
     injector, mocker, state_machine_thread
-):
+) -> None:
     storage_mock: StorageInterface = injector.get(List[StorageInterface])[0]
 
     mocker.patch.object(MockRobot, "get_inspections", return_value=[])
@@ -187,7 +188,7 @@ def test_state_machine_with_unsuccessful_collection(
         ]
     )
     expected_stored_items = 0
-    assert len(storage_mock.stored_inspections) == expected_stored_items
+    assert len(storage_mock.stored_inspections) == expected_stored_items  # type: ignore
     print(state_machine_thread.state_machine.transitions_list)
     assert (
         state_machine_thread.state_machine.transitions_list == expected_transitions_list
@@ -198,7 +199,7 @@ def test_state_machine_with_successful_mission_stop(
     injector: Injector,
     state_machine_thread: StateMachineThread,
     caplog: pytest.LogCaptureFixture,
-):
+) -> None:
     step: TakeImage = MockStep.take_image_in_coordinate_direction
     mission: Mission = Mission(tasks=[Task(steps=[step])])
     scheduling_utilities: SchedulingUtilities = injector.get(SchedulingUtilities)
@@ -214,7 +215,10 @@ def test_state_machine_with_successful_mission_stop(
         ]
     )
     actual = state_machine_thread.state_machine.transitions_list
-    unexpected_log = "Could not communicate request: Reached limit for stop attemps. Cancelled mission and transitioned to idle."
+    unexpected_log = (
+        "Could not communicate request: Reached limit for stop attempts. "
+        "Cancelled mission and transitioned to idle."
+    )
     assert unexpected_log not in caplog.text
     assert expected == actual
 
@@ -224,12 +228,12 @@ def test_state_machine_with_unsuccsessful_mission_stop(
     mocker: MockerFixture,
     state_machine_thread: StateMachineThread,
     caplog: pytest.LogCaptureFixture,
-):
+) -> None:
     step: TakeImage = MockStep.take_image_in_coordinate_direction
     mission: Mission = Mission(tasks=[Task(steps=[step])])
     scheduling_utilities: SchedulingUtilities = injector.get(SchedulingUtilities)
     scheduling_utilities.start_mission(mission=mission, initial_pose=None)
-    mocker.patch.object(ThreadedRequest, "_is_thread_alive", return_value=True)
+    mocker.patch.object(ThreadedRequest, "get_output", side_effect=RobotException)
     scheduling_utilities.stop_mission()
     expected = deque(
         [
@@ -241,6 +245,9 @@ def test_state_machine_with_unsuccsessful_mission_stop(
         ]
     )
     actual = state_machine_thread.state_machine.transitions_list
-    expected_log = "Could not communicate request: Reached limit for stop attemps. Cancelled mission and transitioned to idle."
+    expected_log = (
+        "Could not communicate request: Reached limit for stop attempts. "
+        "Cancelled mission and transitioned to idle."
+    )
     assert expected_log in caplog.text
     assert expected == actual
